@@ -15,10 +15,11 @@ import (
 	"github.com/helmfile/helmfile/pkg/envvar"
 	"github.com/helmfile/helmfile/pkg/errors"
 	"github.com/helmfile/helmfile/pkg/helmexec"
+	"github.com/helmfile/helmfile/pkg/runtime"
 )
 
 var logger *zap.SugaredLogger
-var globalUsage = "Declaratively deploy your Kubernetes manifests, Kustomize configs, and Charts as Helm releases in one shot"
+var globalUsage = "Declaratively deploy your Kubernetes manifests, Kustomize configs, and Charts as Helm releases in one shot\n" + runtime.Info()
 
 func toCLIError(g *config.GlobalImpl, err error) error {
 	if err != nil {
@@ -85,8 +86,6 @@ func NewRootCmd(globalConfig *config.GlobalOptions) (*cobra.Command, error) {
 		NewApplyCmd(globalImpl),
 		NewBuildCmd(globalImpl),
 		NewCacheCmd(globalImpl),
-		NewChartsCmd(globalImpl),
-		NewDeleteCmd(globalImpl),
 		NewDepsCmd(globalImpl),
 		NewDestroyCmd(globalImpl),
 		NewFetchCmd(globalImpl),
@@ -104,6 +103,14 @@ func NewRootCmd(globalConfig *config.GlobalOptions) (*cobra.Command, error) {
 		),
 	)
 
+	// TODO: Remove this function once Helmfile v0.x
+	if !runtime.V1Mode {
+		cmd.AddCommand(
+			NewChartsCmd(globalImpl),
+			NewDeleteCmd(globalImpl),
+		)
+	}
+
 	return cmd, nil
 }
 
