@@ -3,7 +3,6 @@ package app
 import (
 	"bytes"
 	"fmt"
-	"log"
 	"os"
 	"path/filepath"
 	"sort"
@@ -11,7 +10,7 @@ import (
 	"sync"
 	"text/tabwriter"
 
-	"github.com/variantdev/vals"
+	"github.com/helmfile/vals"
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/argparser"
@@ -19,6 +18,7 @@ import (
 	"github.com/helmfile/helmfile/pkg/helmexec"
 	"github.com/helmfile/helmfile/pkg/plugins"
 	"github.com/helmfile/helmfile/pkg/remote"
+	"github.com/helmfile/helmfile/pkg/runtime"
 	"github.com/helmfile/helmfile/pkg/state"
 )
 
@@ -455,36 +455,41 @@ func (a *App) Status(c StatusesConfigProvider) error {
 // TODO: Remove this function once Helmfile v0.x
 func (a *App) Delete(c DeleteConfigProvider) error {
 	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
-		err := run.withPreparedCharts("delete", state.ChartPrepareOptions{
-			SkipRepos:   c.SkipDeps(),
-			SkipDeps:    c.SkipDeps(),
-			Concurrency: c.Concurrency(),
-		}, func() {
+		if !c.SkipCharts() {
+			err := run.withPreparedCharts("delete", state.ChartPrepareOptions{
+				SkipRepos:   c.SkipDeps(),
+				SkipDeps:    c.SkipDeps(),
+				Concurrency: c.Concurrency(),
+			}, func() {
+				ok, errs = a.delete(run, c.Purge(), c)
+			})
+
+			if err != nil {
+				errs = append(errs, err)
+			}
+		} else {
 			ok, errs = a.delete(run, c.Purge(), c)
-		})
-
-		if err != nil {
-			errs = append(errs, err)
 		}
-
 		return
 	}, false, SetReverse(true))
 }
 
 func (a *App) Destroy(c DestroyConfigProvider) error {
 	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
-		err := run.withPreparedCharts("destroy", state.ChartPrepareOptions{
-			SkipRepos:   c.SkipDeps(),
-			SkipDeps:    c.SkipDeps(),
-			Concurrency: c.Concurrency(),
-		}, func() {
+		if !c.SkipCharts() {
+			err := run.withPreparedCharts("destroy", state.ChartPrepareOptions{
+				SkipRepos:   c.SkipDeps(),
+				SkipDeps:    c.SkipDeps(),
+				Concurrency: c.Concurrency(),
+			}, func() {
+				ok, errs = a.delete(run, true, c)
+			})
+			if err != nil {
+				errs = append(errs, err)
+			}
+		} else {
 			ok, errs = a.delete(run, true, c)
-		})
-
-		if err != nil {
-			errs = append(errs, err)
 		}
-
 		return
 	}, false, SetReverse(true))
 }
@@ -938,7 +943,10 @@ func (a *App) ForEachState(do func(*Run) (bool, []error), includeTransitiveNeeds
 	err := a.visitStatesWithSelectorsAndRemoteSupport(a.FileOrDir, func(st *state.HelmState) (bool, []error) {
 		helm := a.getHelm(st)
 
-		run := NewRun(st, helm, ctx)
+		run, err := NewRun(st, helm, ctx)
+		if err != nil {
+			return false, []error{err}
+		}
 		return do(run)
 	}, includeTransitiveNeeds, o...)
 
@@ -1153,12 +1161,20 @@ func (a *App) findDesiredStateFiles(specifiedPath string, opts LoadOpts) ([]stri
 		}
 	} else {
 		var defaultFile string
-		if a.fs.FileExistsAt(DefaultHelmfile) {
+		DefaultGotmplHelmfile := DefaultHelmfile + ".gotmpl"
+		if a.fs.FileExistsAt(DefaultHelmfile) && a.fs.FileExistsAt(DefaultGotmplHelmfile) {
+			return []string{}, fmt.Errorf("both %s and %s.gotmpl exist. Please remove one of them", DefaultHelmfile, DefaultHelmfile)
+		}
+		switch {
+		case a.fs.FileExistsAt(DefaultHelmfile):
 			defaultFile = DefaultHelmfile
 
-			// TODO: Remove this function once Helmfile v0.x
-		} else if a.fs.FileExistsAt(DeprecatedHelmfile) {
-			log.Printf(
+		case a.fs.FileExistsAt(DefaultGotmplHelmfile):
+			defaultFile = DefaultGotmplHelmfile
+
+		// TODO: Remove this block when we remove v0 code
+		case !runtime.V1Mode && a.fs.FileExistsAt(DeprecatedHelmfile):
+			a.Logger.Warnf(
 				"warn: %s is being loaded: %s is deprecated in favor of %s. See https://github.com/roboll/helmfile/issues/25 for more information",
 				DeprecatedHelmfile,
 				DeprecatedHelmfile,
@@ -1177,14 +1193,24 @@ func (a *App) findDesiredStateFiles(specifiedPath string, opts LoadOpts) ([]stri
 		case defaultFile != "":
 			return []string{defaultFile}, nil
 		default:
-			return []string{}, fmt.Errorf("no state file found. It must be named %s/*.{yaml,yml} or %s, otherwise specified with the --file flag", DefaultHelmfileDirectory, DefaultHelmfile)
+			return []string{}, fmt.Errorf("no state file found. It must be named %s/*.{yaml,yml,yaml.gotmpl,yml.gotmpl}, %s, or %s, otherwise specified with the --file flag", DefaultHelmfileDirectory, DefaultHelmfile, DefaultGotmplHelmfile)
 		}
 	}
 
-	files, err := a.fs.Glob(filepath.Join(helmfileDir, "*.y*ml"))
+	files := []string{}
+
+	ymlFiles, err := a.fs.Glob(filepath.Join(helmfileDir, "*.y*ml"))
 	if err != nil {
 		return []string{}, err
 	}
+	gotmplFiles, err := a.fs.Glob(filepath.Join(helmfileDir, "*.y*ml.gotmpl"))
+	if err != nil {
+		return []string{}, err
+	}
+
+	files = append(files, ymlFiles...)
+	files = append(files, gotmplFiles...)
+
 	if opts.Reverse {
 		sort.Slice(files, func(i, j int) bool {
 			return files[j] < files[i]
@@ -1194,6 +1220,9 @@ func (a *App) findDesiredStateFiles(specifiedPath string, opts LoadOpts) ([]stri
 			return files[i] < files[j]
 		})
 	}
+
+	a.Logger.Debugf("found %d helmfile state files in %s: %s", len(ymlFiles)+len(gotmplFiles), helmfileDir, strings.Join(files, ", "))
+
 	return files, nil
 }
 
@@ -1540,6 +1569,7 @@ func (a *App) diff(r *Run, c DiffConfigProvider) (*string, bool, bool, []error)
 		helm := r.helm
 
 		helm.SetExtraArgs(argparser.GetArgs(c.Args(), r.state)...)
+		helm.SetPostRenderer(c.PostRenderer())
 
 		var errs []error
 
@@ -1844,6 +1874,8 @@ func (a *App) template(r *Run, c TemplateConfigProvider) (bool, []error) {
 			helm.SetExtraArgs(args...)
 		}
 
+		helm.SetPostRenderer(c.PostRenderer())
+
 		opts := &state.TemplateOpts{
 			Set:               c.Set(),
 			IncludeCRDs:       c.IncludeCRDs(),
