@@ -6,8 +6,8 @@ import (
 	"fmt"
 	"path/filepath"
 
+	"github.com/helmfile/vals"
 	"github.com/imdario/mergo"
-	"github.com/variantdev/vals"
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/environment"
@@ -220,12 +220,6 @@ func (ld *desiredStateLoader) load(env, overrodeEnv *environment.Environment, ba
 			return nil, err
 		}
 
-		for i, r := range currentState.Releases {
-			if r.Chart == "" {
-				return nil, fmt.Errorf("error during %s parsing: encountered empty chart while reading release %q at index %d", id, r.Name, i)
-			}
-		}
-
 		if finalState == nil {
 			finalState = currentState
 		} else {
