@@ -6,6 +6,8 @@ type DestroyOptions struct {
 	Concurrency int
 	// SkipDeps is the skip deps flag
 	SkipDeps bool
+	// SkipCharts makes Destroy skip `withPreparedCharts`
+	SkipCharts bool
 }
 
 // NewDestroyOptions creates a new Apply
@@ -36,3 +38,8 @@ func (c *DestroyImpl) Concurrency() int {
 func (c *DestroyImpl) SkipDeps() bool {
 	return c.DestroyOptions.SkipDeps
 }
+
+// SkipCharts returns skipCharts flag
+func (c *DestroyImpl) SkipCharts() bool {
+	return c.DestroyOptions.SkipCharts
+}
