@@ -9,4 +9,7 @@ const (
 	TempDir                       = "HELMFILE_TEMPDIR"
 	Helm3                         = "HELMFILE_HELM3"
 	UpgradeNoticeDisabled         = "HELMFILE_UPGRADE_NOTICE_DISABLED"
+	V1Mode                        = "HELMFILE_V1MODE"
+	GoccyGoYaml                   = "HELMFILE_GOCCY_GOYAML"
+	CacheHome                     = "HELMFILE_CACHE_HOME"
 )
