@@ -9,13 +9,11 @@ import (
 
 	"github.com/Masterminds/semver/v3"
 	goversion "github.com/hashicorp/go-version"
-	"github.com/r3labs/diff"
 	"go.uber.org/zap"
-	"gopkg.in/yaml.v3"
 
 	"github.com/helmfile/helmfile/pkg/app/version"
 	"github.com/helmfile/helmfile/pkg/helmexec"
-	"github.com/helmfile/helmfile/pkg/maputil"
+	"github.com/helmfile/helmfile/pkg/yaml"
 )
 
 type ChartMeta struct {
@@ -279,7 +277,6 @@ type chartDependencyManager struct {
 	writeFile func(string, []byte, os.FileMode) error
 }
 
-// nolint: golint
 func NewChartDependencyManager(name string, logger *zap.SugaredLogger, lockFilePath string) *chartDependencyManager {
 	return &chartDependencyManager{
 		Name:         name,
@@ -299,10 +296,7 @@ func (m *chartDependencyManager) lockFileName() string {
 }
 
 func (m *chartDependencyManager) Update(shell helmexec.DependencyUpdater, wd string, unresolved *UnresolvedDependencies) (*ResolvedDependencies, error) {
-	if shell.IsHelm3() {
-		return m.updateHelm3(shell, wd, unresolved)
-	}
-	return m.updateHelm2(shell, wd, unresolved)
+	return m.updateHelm3(shell, wd, unresolved)
 }
 
 func (m *chartDependencyManager) updateHelm3(shell helmexec.DependencyUpdater, wd string, unresolved *UnresolvedDependencies) (*ResolvedDependencies, error) {
@@ -310,7 +304,7 @@ func (m *chartDependencyManager) updateHelm3(shell helmexec.DependencyUpdater, w
 	chartMetaContent := fmt.Sprintf("name: %s\nversion: 1.0.0\napiVersion: v2\n", m.Name)
 
 	// Generate `requirements.yaml` of the temporary local chart from the helmfile state
-	reqsContent, err := maputil.YamlMarshal(unresolved.ToChartRequirements())
+	reqsContent, err := yaml.Marshal(unresolved.ToChartRequirements())
 	if err != nil {
 		return nil, err
 	}
@@ -321,24 +315,6 @@ func (m *chartDependencyManager) updateHelm3(shell helmexec.DependencyUpdater, w
 	return m.doUpdate("Chart.lock", unresolved, shell, wd)
 }
 
-func (m *chartDependencyManager) updateHelm2(shell helmexec.DependencyUpdater, wd string, unresolved *UnresolvedDependencies) (*ResolvedDependencies, error) {
-	// Generate `Chart.yaml` of the temporary local chart
-	if err := m.writeBytes(filepath.Join(wd, "Chart.yaml"), []byte(fmt.Sprintf("name: %s\nversion: 1.0.0\n", m.Name))); err != nil {
-		return nil, err
-	}
-
-	// Generate `requirements.yaml` of the temporary local chart from the helmfile state
-	reqsContent, err := maputil.YamlMarshal(unresolved.ToChartRequirements())
-	if err != nil {
-		return nil, err
-	}
-	if err := m.writeBytes(filepath.Join(wd, "requirements.yaml"), reqsContent); err != nil {
-		return nil, err
-	}
-
-	return m.doUpdate("requirements.lock", unresolved, shell, wd)
-}
-
 func (m *chartDependencyManager) doUpdate(chartLockFile string, unresolved *UnresolvedDependencies, shell helmexec.DependencyUpdater, wd string) (*ResolvedDependencies, error) {
 	// Generate `requirements.lock` of the temporary local chart by coping `<basename>.lock`
 	lockFilePath := m.lockFileName()
@@ -348,7 +324,7 @@ func (m *chartDependencyManager) doUpdate(chartLockFile string, unresolved *Unre
 		return nil, err
 	}
 
-	if shell.IsHelm3() && originalLockFileContent != nil {
+	if originalLockFileContent != nil {
 		if err := m.writeBytes(filepath.Join(wd, chartLockFile), originalLockFileContent); err != nil {
 			return nil, err
 		}
@@ -374,27 +350,9 @@ func (m *chartDependencyManager) doUpdate(chartLockFile string, unresolved *Unre
 		return lockedReqs.ResolvedDependencies[i].ChartName < lockedReqs.ResolvedDependencies[j].ChartName
 	})
 
-	// Don't update lock file if no dependency updated.
-	if !shell.IsHelm3() && originalLockFileContent != nil {
-		originalLockedReqs := &ChartLockedRequirements{}
-		if err := yaml.Unmarshal(originalLockFileContent, originalLockedReqs); err != nil {
-			return nil, err
-		}
-
-		changes, err := diff.Diff(originalLockedReqs.ResolvedDependencies, lockedReqs.ResolvedDependencies)
-
-		if err != nil {
-			return nil, err
-		}
-
-		if len(changes) == 0 {
-			lockedReqs.Generated = originalLockedReqs.Generated
-		}
-	}
-
 	lockedReqs.Version = version.Version()
 
-	updatedLockFileContent, err = maputil.YamlMarshal(lockedReqs)
+	updatedLockFileContent, err = yaml.Marshal(lockedReqs)
 
 	if err != nil {
 		return nil, err
