@@ -5,8 +5,8 @@ import (
 	"fmt"
 	"io"
 
+	"github.com/helmfile/vals"
 	"github.com/imdario/mergo"
-	"github.com/variantdev/vals"
 	"go.uber.org/zap"
 
 	"github.com/helmfile/helmfile/pkg/environment"
@@ -96,6 +96,8 @@ func (c *StateCreator) Parse(content []byte, baseDir, file string) (*HelmState,
 
 		var intermediate HelmState
 
+		intermediate.FilePath = file
+
 		err := decode(&intermediate)
 		if err == io.EOF {
 			break
@@ -227,7 +229,7 @@ func (c *StateCreator) loadEnvValues(st *HelmState, name string, failOnMissingEn
 		if len(envSpec.Secrets) > 0 {
 			var envSecretFiles []string
 			for _, urlOrPath := range envSpec.Secrets {
-				resolved, skipped, err := st.storage().resolveFile(envSpec.MissingFileHandler, "environment values", urlOrPath)
+				resolved, skipped, err := st.storage().resolveFile(envSpec.MissingFileHandler, "environment values", urlOrPath, envSpec.MissingFileHandlerConfig.resolveFileOptions()...)
 				if err != nil {
 					return nil, err
 				}
